GroupMember — alfred3_interact

Skip to main content
`Ctrl`+`K`

# GroupMember

class alfred3_interact.member.GroupMember(matchmaker, **data)

  Bases: `object`

  The group member object grants access to a member’s experiment data.

  The group member object’s most important job is to provide easy access to the member’s experiment data through the following attributes. They provide the same objects as the corresponding attributes of the `alfred3.experiment.ExperimentSession` object:

  - `values`

  - `session_data`

  - `metadata`

  - `client_data`

  - `adata`

  Methods

  Attributes

  `adata` | Dictionary of additional data.
  `additional_data` | Alias for `adata`
  `client_data` | Dictionary of client data.
  `group_id` | If the member is associated with a group, this property returns the group id.
  `matched` | Indicates whether the member is associated with a group.
  `metadata` | Dictionary of experiment metadata.
  `move_history` | Dictionary of movement history.
  `role` | The member's role.
  `session_data` | Full dictionary of experiment session data.
  `values` | Flat dictionary of input element values.